# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/wow_catalog/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\WowCatalog\\": "packages/litecms/wow_catalog/src",
            "Litecms\\WowCatalog\\Seeders\\": "packages/litecms/wow_catalog/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\WowCatalog\Providers\WowCatalogServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'WowCatalog'  => Litecms\WowCatalog\Facades\WowCatalog::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\WowCatalog\\Seeders\\WowCatalogTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\WowCatalog\Providers\WowCatalogServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\WowCatalog\Providers\WowCatalogServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\WowCatalog\Providers\WowCatalogServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/wow_catalog/{modulename}

**User**

    http://path-to-route-folder/user/wow_catalog/{modulename}

**Public**

    http://path-to-route-folder/wow_catalogs


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/wow_catalog/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/wow_catalog/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/wow_catalog/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/wow_catalog/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/wow_catalog/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/wow_catalog/{modulename}/{slug}
    METHOD: GET