<?php

namespace Litecms\WowCatalog\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litecms\WowCatalog\Models\WowCatalog;

use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\WowCatalog\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/wow_catalog/wow_catalog_product/*')) {
            Route::bind('wow_catalog_product', function ($wow_catalog_product) {
                $wow_catalog_productRepo = $this->app->make('Litecms\WowCatalog\Interfaces\WowCatalogProductRepositoryInterface');
                return $wow_catalog_productRepo->findorNew($wow_catalog_product);
            });
        }
        if (Request::is('*/wow_catalog/wow_catalog_category/*')) {
            Route::bind('wow_catalog_category', function ($wow_catalog_category) {
                $wow_catalog_categoryRepo = $this->app->make('Litecms\WowCatalog\Interfaces\WowCatalogCategoryRepositoryInterface');
                return $wow_catalog_categoryRepo->findorNew($wow_catalog_category);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
