<?php

namespace Litecms\WowCatalog\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\WowCatalog\WowCatalogs;

class WowCatalogServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'wow_catalog');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'wow_catalog');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Litecms\WowCatalog\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\WowCatalog\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litecms\WowCatalog\Providers\EventServiceProvider::class);
        // $this->app->register(\Litecms\WowCatalog\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.wow_catalog', function($app)
        {
            return $this->app->make(WowCatalogs::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind WowCatalogProduct to repository
        $this->app->bind(
            'Litecms\WowCatalog\Interfaces\WowCatalogProductRepositoryInterface',
            \Litecms\WowCatalog\Repositories\Eloquent\WowCatalogProductRepository::class
        );        // Bind WowCatalogCategory to repository
        $this->app->bind(
            'Litecms\WowCatalog\Interfaces\WowCatalogCategoryRepositoryInterface',
            \Litecms\WowCatalog\Repositories\Eloquent\WowCatalogCategoryRepository::class
        );
    }


    /**
     * Merges user's and wow_catalog's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.wow_catalog'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litecms\WowCatalog\Commands\WowCatalog::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.wow_catalog'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/wow_catalog.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/wow_catalog')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/wow_catalog')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
